*************************************************************************************************************
* Data: 	Uribe, A. 2011. "Gridded Analysis of Meteorological Variables in Nicaragua." The World Bank.    *
* Purpose: 	Replicating Table A.2 in Transfers, Diversification and Household Risk Strategies:  		 	*
*		    Can productive safety nets help households manage climate variability? 			  				*				                                   				 	  		*
*************************************************************************************************************

capture clear
capture log close



set more off
set graphics off

********************************************************************************
* TEMPERATURE 1979 - 2008
********************************************************************************
	
	use "Uribe_temperature.dta", clear
		
		gen doy = doy(date) 
		gen woy = week(date) 
		sort month day 
		egen monthday = group(month day), label 
		gen agr_season = (inrange(month,4, 11))
		
		gen period = . 
		replace period = 1 if (year < 1998) 
		replace period = 2 if (year == 1998)
		replace period = 3 if year > 1998 & year <= 2008

		egen temp_mean = rowmean(temp_max temp_min) 

		* Labelling vars 
		la var temp_mean 	"TMean"
		la var doy			"Day of the year" 
		la var woy			"Week of the year"
		la var monthday 	"Month-day combination" 
		la var agr_season	"Agricultural season" 
		la var nid			"ID of the center of the grid" 
		
		order nid date year month day agr_season monthday woy doy temp*	
		sort nid date
		
	
	label define period_unit 1 "Pre 1998" 2 "Year 1998" 3 "Post 1998"
	label values period period_unit
	
	*·················································································
	* Replicating Table A.2 - temperature descriptives
	*·················································································
	
	tab period, gen(pd)
	tab nid, gen(nid_dv)
	
	* Table settings & format 
	putexcel set "Tables.xls", sheet("Table_A2") replace
	putexcel A2 = "Table A.2: Significant changes in rainfall and temperature patterns" 
	putexcel A4 = "Temperature", bold underline
	putexcel A1:E1, border(bottom) bold
	putexcel B3 = "Pre-1998" C3 = "Post-1998" D3 = "Diff." E3 = "P-value diff.", hcenter
	putexcel B3:E3, border(bottom) bold

	mata: b = xl()
	mata: b.load_book("Tables.xls")
	mata: b.set_sheet("Table_A2")
	mata: b.set_column_width(1,1,65)
	mata: b.set_column_width(2,8,20)

	* Daily max during agricultural season  ------------------------------------
		preserve 
			collapse (mean) temp_max temp_min temp_mean (max) pd* nid_dv*, by(year agr_season nid period) 
			
			la var temp_max		"Daily max during agricultural seasons: Apr to Nov. (C°)"		
			la var temp_min		"Daily min during agricultural seasons: Apr to Nov. (C°)"		
			la var temp_mean 	"Daily mean during agricultural seasons: Apr to Nov. (C°)"	
			
			la var pd1 "Pre 1998" 
			la var pd2 "Year 1998" 
			la var pd3 "Post 1998" 
			
			keep if (period == 1 | period == 3) & agr_season == 1
			xtset nid year 

			* Fixed Effects regression - no nested clustering at year 
			
			local row = 5
			foreach x in temp_max {
		
			putexcel set "Tables.xls", sheet("Table_A2") modify
			
			* Set up labels in first column 
			local varlabel : var label `x'
			putexcel A`row' = ("`varlabel'")
			
			* Coefficients -  Pre 1998 and Differences 
			xtreg `x' pd3, fe vce(cluster year) nonest
			putexcel B`row' = _b[_cons] , nformat(number_d2)
			putexcel D`row' =  _b[pd3] , nformat(number_d2)
				
			*T-test comparing periods A-B
			test  pd3
			putexcel E`row' = `r(p)' , nformat(number_d2)

			* Coefficients - Post 1998 & Post 2008 
			xtreg `x' pd1, fe vce(cluster year) nonest
			putexcel C`row' =  _b[_cons] , nformat(number_d2)

			local row = `row'+1		
			}
			
		restore
				
		* Daily max during June and July ---------------------------------------
		
		gen junjuly = (month == 6 | month == 7) 
		
		* Generate median pre 1998 daily temp pixel specific 
		bysort period month day nid: egen median_temp = median(temp_mean)
		bysort nid: gen med_temp_p1_v0 = median_temp if period == 1 
		bysort nid month day: egen med_temp_p1 = mean(med_temp_p1_v0)
		drop med_temp_p1_v0
		
		preserve 
			collapse (mean) temp_max temp_min temp_mean (max) pd* nid_dv* med_temp_p1, by(nid year junjuly period) 
			
			la var temp_max		"Daily max during June and July (C°)"		
			la var temp_min		"Daily min during June and July (C°)"		
			la var temp_mean	"Daily mean during June and July (C°)"	
			la var med_temp_p1	"Pre 1998 median temperature (C°) - nid specific"
			
			la var pd1 "Pre 1998" 
			la var pd2 "Year 1998" 
			la var pd3 "Post 1998" 
			
			keep if (period == 1 | period == 3) & junjuly == 1
			xtset nid year 

			* Fixed Effects regression - no nested clustering at year 
			
			local row = 6
			
			foreach x in temp_max {
			* Set up labels in first column 
			local varlabel : var label `x'
			putexcel A`row' = ("`varlabel'")
			
			* Coefficients -  Pre 1998 and Differences 
			xtreg `x' pd3, fe vce(cluster year) nonest
			putexcel B`row' = _b[_cons] , nformat(number_d2)
			putexcel D`row' =  _b[pd3] , nformat(number_d2)				
			*T-test comparing periods A-B
			test  pd3
			putexcel E`row' = `r(p)' , nformat(number_d2)

			* Coefficients - Post 1998 & Post 2008 
			xtreg `x' pd1, fe vce(cluster year) nonest
			putexcel C`row' =  _b[_cons] , nformat(number_d2)
			local row = `row'+1		
			}				
		restore
		
		* Degree-days in June and July -----------------------------------------
		
		* Define degree days 
		gen degree_days = . 
		replace degree_days = 0 if temp_mean < 8 
		replace degree_days = temp_mean - 8 if temp_mean >= 8 & temp_mean <= 32
		replace degree_days = 24 if temp_mean > 32
		replace degree_days = . if missing(temp_mean)
		
		* Sum degree days for June & July per year & nid 
		preserve 
			collapse (sum) dd_67 = degree_days (max) pd* nid_dv* period, by(nid year junjuly) 
			
			la var dd_67 		"Degree days in June and July (C°)"
			la var pd1 			"Pre 1998" 
			la var pd2 			"Year 1998" 
			la var pd3 			"Post 1998" 
			
			keep if (period == 1 | period == 3) & junjuly == 1
			drop junjuly 
			xtset nid year 
	
			* Fixed Effects regression - no nested clustering at year 
			
			local row = 7
			foreach x in dd_67 {
			
			putexcel set "Tables.xls", sheet("Table_A2")  modify
			
			* Set up labels in first column 
			local varlabel : var label `x'
			putexcel A`row' = ("`varlabel'")
			
			* Coefficients -  Pre 1998 and Differences 
			xtreg `x' pd3, fe vce(cluster year) nonest
			putexcel B`row' = _b[_cons] , nformat(number)
			putexcel D`row' =  _b[pd3] , nformat(number)
				
			*T-test comparing periods A-B
			test  pd3
			putexcel E`row' = `r(p)' , nformat(number_d2)

			* Coefficients - Post 1998 & Post 2008
			xtreg `x' pd1, fe vce(cluster year) nonest
			putexcel C`row' =  _b[_cons] , nformat(number)
			local row = `row'+1		
			}	
		restore 
	
********************************************************************************
* RAINFALL 1979 - 2008 
********************************************************************************
	
	use "Uribe_rainfall.dta", clear 
	
	gen doy = doy(date) 
	gen woy = week(date) 

	sort month day 
	egen monthday = group(month day), label 
	lab var monthday "Month-Day" 
	
	gen agr_season = (month >=4 & month <= 11) 

	gen period = . 
	replace period = 1 if (year < 1998) 
	replace period = 2 if (year == 1998)
	replace period = 3 if (year > 1998 & year <= 2008) 
	
	*·················································································
	* Replicating Table A.2 - rainfall descriptives
	*·················································································

	tab period, gen(pd)
	tab nid, gen(nid_dv)

	putexcel set "Tables.xls", sheet("Table_A2") modify
	putexcel A9 = "Rainfall", bold underline
	
			* Total rainfall Apr-Nov (mm) --------------------------------------
		preserve 
			collapse (sum) prcip (max) pd* nid_dv*, by(year agr_season nid period) 
			
			la var prcip	"Total Rainfall Apr-Nov (mm)"		

			la var pd1 "Pre 1998" 
			la var pd2 "Year 1998" 
			la var pd3 "Post 1998" 
			
			keep if (pd1 == 1 | pd3 == 1) & agr_season == 1
			xtset nid year 

			* Fixed Effects Regression with non-nested cluster at year 
			
			local row = 10
			
			* Set up labels in first column 
			local varlabel : var label prcip
			putexcel A`row' = ("`varlabel'")
			
			* Coefficients -  Pre and Difference 
			xtreg prcip pd3, fe vce(cluster year) nonest
			putexcel B`row' = _b[_cons] , nformat(number)
			putexcel D`row' =  _b[pd3] , nformat(number_d2)
					
			*T-test comparing periods 
			test  pd3
			putexcel E`row' = `r(p)' , nformat(number_d2)
						
			* Coefficients - Post 1998 
			xtreg prcip pd1, fe vce(cluster year) nonest
			putexcel C`row' =  _b[_cons] , nformat(number)

			local row = `row'+1		
		restore 
		
			* Standard deviation daily rainfall (April - November) -------------
		preserve 
			bysort nid year agr_season: egen sd_prcip = sd(prcip)
		
			* Labelling vars 
			la var sd_prcip 	"Standard deviation daily rainfall (April-Nov)"
				
			* Keeping relevant data 
			keep if agr_season == 1 & (period == 1 | period == 3)
			bysort nid year: keep if _n == 1
			xtset nid year 
			
			* Fixed Effects Regression with non-nested cluster at year 
			
			local row = 11
		
			* Set up labels in first column 
			local varlabel : var label sd_prcip
			putexcel A`row' = ("`varlabel'")
			
			* Coefficients -  Pre and Difference
			xtreg sd_prcip pd3, fe vce(cluster year) nonest
			putexcel B`row' = _b[_cons] , nformat(number)
			putexcel D`row' =  _b[pd3] , nformat(number_d2)
					
			*T-test comparing periods 
			test  pd3
			putexcel E`row' = `r(p)' , nformat(number_d2)
	
			* Coefficients - Post 1998 
			xtreg sd_prcip pd1, fe vce(cluster year) nonest
			putexcel C`row' =  _b[_cons] , nformat(number)
		restore 

			* Total rainfall by month (mm) -------------------------------------
		preserve 
			collapse (sum) prcip (max) pd* nid_dv* period, by(year month nid ) 
			
			bysort year nid : egen precip_apr = mean(prcip) if month == 4
			bysort year nid : egen precip_nov = mean(prcip) if month == 11
			bysort year nid : egen prcip_apr = mean(precip_apr) 
			bysort year nid : egen prcip_nov = mean(precip_nov)
			drop precip_apr precip_nov
			
			* Delete 1998 year 
			keep if (period == 1 | period == 3)
			
			* Keep 1 ob per node-year
			bysort year nid : keep if _n == 1 
	
			xtset nid year  
					
			* Labelling vars 
			la var prcip_apr		"Total Rainfall April (mm)"
			la var prcip_nov		"Total Rainfall November (mm)"
		
			la var pd1 "Pre 1998" 
			la var pd2 "Year 1998" 
			la var pd3 "Post 1998" 
		
			* Fixed Effects Regression with non-nested cluster at year 
		
			local row = 12
			foreach x of varlist prcip_apr prcip_nov {
			
				* Set up labels in first column 
				local varlabel : var label `x'
				putexcel A`row' = ("`varlabel'")
				
				* Coefficients -  Pre and Difference 
				xtreg `x' pd3, fe vce(cluster year) nonest
				putexcel B`row' = _b[_cons] , nformat(number)
				putexcel D`row' = _b[pd3] , nformat(number_d2)
						
				*T-test comparing periods 
				test  pd3
				putexcel E`row' = `r(p)' , nformat(number_d2)
							
				* Coefficients - Post 1998 
				xtreg `x' pd1, fe vce(cluster year) nonest
				putexcel C`row' =  _b[_cons] , nformat(number)
				
				local row = `row'+1		
			}
		restore 
		
		
		* Start of rainy season (1st 5day-spell with at least 15mm cumulative rainfall)-----
								
			* Create rainfall spells foreach year 
			forvalues j = 1979/2008{
			preserve
				keep if year == `j' 
				tsset nid date, daily
				tsspell prcip, cond(prcip > 0 & prcip~=.)
				* There is rain in the day 
				gen hadrain		 	= (prcip > 0 & prcip~=.)
				* There is rain in the last 5 days 
				gen rain5days_yes 	= (hadrain + L1.hadrain + L2.hadrain + L3.hadrain + L4.hadrain)/5
				replace rain5days_yes = 0 if rain5days_yes !=. & rain5days_yes !=1 
				* Cumulative rain in the last 5 days 
				gen cum5daysrain 	= (prcip + L1.prcip + L2.prcip + L3.prcip + L4.prcip)
				* First day with the 5 previous days with rain & acc rain > 15 mm & date > 90th day of the year 
				by nid year (date), sort: egen fst_prcip_0 = min(doy) if cum5daysrain>=15 & rain5days_yes == 1 & doy >= 90 
					* No rainy season if day of the year > 264th day of the year
					replace fst_prcip_0 = 0 if fst_prcip_0 > 264 & fst_prcip_0 !=. 
				bysort nid year (date): egen st_wetseason	= mean(fst_prcip_0)
				* Subtract 1 day if the year has 366 days
					count if doy == 366 
					 if r(N)>0 {
					 replace st_wetseason = st_wetseason - 1 
					}
					* Replace to 0 if no start of the rainy season 
					ta nid if st_wetseason == .
					replace st_wetseason = 0 if st_wetseason ==.
				* Labelling 
				capture lab var st_wetseason 	"Start of rainy season (5 days with 15 mm cumulative rainfall)"
				keep nid year date doy prcip hadrain cum5daysrain rain5days_yes fst_prcip_0 st_wetseason
				save spell_`j'.dta , replace 
			restore 
			}
			
			* Merging for each year the start of the season 
			forvalues j = 1979/2008{ 
			merge m:1 nid year date using spell_`j', nogen update 
			erase spell_`j'.dta 
			}
			
			* Keeping relevant data 
			preserve
				bysort nid year: keep if _n == 1
				keep if (period == 1 | period == 3)
			
				local row = 14
				foreach x of varlist st_wetseason { 
					xtset nid year 
					
					* Fixed Effects Regression with non-nested cluster year 
					
					* Set up labels in first column 
					local varlabel : var label `x'
					putexcel A`row' = ("`varlabel'")

					* Coefficients -  Pre and Difference 
					xtreg `x' pd3, fe vce(cluster year) nonest
					putexcel B`row' = _b[_cons] , nformat(number)
					putexcel D`row' =  _b[pd3] , nformat(number_d2)
					
					*T-test comparing periods 
					test  pd3
					putexcel E`row' = `r(p)' , nformat(number_d2)
					
					* Coefficients - Post 1998 
					xtreg `x' pd1, fe vce(cluster year) nonest
					putexcel C`row' =  _b[_cons] , nformat(number)
					
					local row = `row'+1		
					}
			restore
	
		
		
